YARP 2.3.61 (2014-01-31)                                              {#v2_3_61}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.60...v2.3.61`):

```
     2	Matteo Brunettini <matteo.brunettini@iit.it>
     1	Alberto Cardellino <alberto.cardellino@iit.it>
     1	Elena Ceseracciu <elena.ceseracciu@iit.it>
     1	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     1	YARP Developers <yarp0-devel@lists.sourceforge.net>
```
